# Boardom

High-ish level toolbox, less boilerplate, PyTorch, loops, code, metrics, blah blah, deep learning, blah.

A continuation of [pydlt](https://github.com/dmarnerides/pydlt). 

# Installation

1. Install Dependencies

```bash
pip install rawpy portalocker tqdm lmdb aiohttp wrapt zmq msgpack numpy matplotlib scipy pandas ordered_set pylatex 
```

2. Install torch and torchvision ([follow instructions here](https://pytorch.org/get-started/locally/))

3. Install OpenCV. Sometimes it's tricky to get right. This should probably be fine:
```bash
pip install opencv-python
```

4. Finally install boardom
```bash
pip install boardom
```

## Contact

Demetris Marnerides: dmarnerides@gmail.com

## NOTE

(A portmanteau of Tensorboard and Visdom.)

Not affiliated with [boardom.io](https://boardom.io/), but that might be what you were looking for!

